@@ -16,11 +16,7 @@ def marc8_to_unicode(marc8, hide_utf8_warnings=False):
     # XXX: might be good to stash away a converter somehow
     # instead of always re-creating it 
     converter = MARC8ToUnicode(quiet=hide_utf8_warnings)
-    try: 
-        return converter.translate(marc8)
-    except IndexError, ie:
-        # convert IndexError into UnicodeDecodeErrors
-        raise UnicodeDecodeError("marc8_to_unicode", marc8, 0, len(marc8), "invalid multibyte character encoding")
+    return converter.translate(marc8)
 
 
 class MARC8ToUnicode:
@@ -62,37 +58,17 @@ class MARC8ToUnicode:
             if marc8_string[pos] == '\x1b':
                 next = marc8_string[pos+1]
                 if (next in self.g0_set):
-                    if len(marc8_string) >= pos + 3:
-                        if marc8_string[pos+2] == ',' and next == '$':
-                            pos += 1
-                        self.g0 = ord(marc8_string[pos+2])
-                        pos = pos + 3
-                        continue
-                    else:
-                        # if there aren't enough remaining characters, readd
-                        # the escape character so it doesn't get lost; may
-                        # help users diagnose problem records
-                        uni_list.append(marc8_string[pos])
+                    if marc8_string[pos+2] == ',' and next == '$':
                         pos += 1
-                        continue
-
+                    self.g0 = ord(marc8_string[pos+2])
+                    pos = pos + 3
+                    continue
                 elif next in self.g1_set:
                     if marc8_string[pos+2] == '-' and next == '$':
                         pos += 1
                     self.g1 = ord(marc8_string[pos+2])
                     pos = pos + 3
                     continue
-                else:
-                    charset = ord(next)
-                    if charset in marc8_mapping.CODESETS:
-                        self.g0 = charset
-                        pos += 2
-                    elif charset == 0x73:
-                        self.g0 = self.basic_latin
-                        pos += 2
-                        if pos == len(marc8_string):
-                            break
-
             
             def is_multibyte(charset):
                 return charset == 0x31
