@@ -1,5 +1,4 @@
 import re
-import logging
 
 from pymarc.exceptions import BaseAddressInvalid, RecordLeaderInvalid, \
         BaseAddressNotFound, RecordDirectoryInvalid, NoFieldsFound, \
@@ -9,66 +8,7 @@ from pymarc.field import Field, SUBFIELD_INDICATOR, END_OF_FIELD, \
         map_marc8_field
 from pymarc.marc8 import marc8_to_unicode
 
-try:
-    # the json module was included in the stdlib in python 2.6
-    # http://docs.python.org/library/json.html
-    import json
-except ImportError:
-    # simplejson 2.0.9 is available for python 2.4+
-    # http://pypi.python.org/pypi/simplejson/2.0.9
-    # simplejson 1.7.3 is available for python 2.3+
-    # http://pypi.python.org/pypi/simplejson/1.7.3
-    import simplejson as json
-
-try:
-    # izip_longest first appeared in python 2.6
-    # http://docs.python.org/library/itertools.html#itertools.izip_longest
-    from itertools import izip_longest
-except ImportError:
-    # itertools was introducted in python 2.3
-    # we just define the required classes and functions
-    # for 2.3 <= python < 2.6 here
-    class ZipExhausted(Exception):
-        pass
-
-    def _next(obj):
-        """
-        ``next`` (http://docs.python.org/library/functions.html#next)
-        was introduced in python 2.6 - and if we are here
-        (no ``izip_longest``), than we need to define this."""
-        return obj.next()
-
-    def izip_longest(*args, **kwds):
-        """
-        Make an iterator that aggregates elements from each of the iterables.
-        If the iterables are of uneven length, missing values are filled-in
-        with fillvalue.
-        Iteration continues until the longest iterable is exhausted.
-
-        This function is available in the standard lib since 2.6.
-        """
-        # chain and repeat are available since python 2.3
-        from itertools import chain, repeat
-
-        # izip_longest('ABCD', 'xy', fillvalue='-') --> Ax By C- D-
-        fillvalue = kwds.get('fillvalue', '')
-        counter = [len(args) - 1]
-        def sentinel():
-            if not counter[0]:
-                raise ZipExhausted
-            counter[0] -= 1
-            yield fillvalue
-        fillers = repeat(fillvalue)
-        iterators = [chain(it, sentinel(), fillers) for it in args]
-        try:
-            while iterators:
-                yield tuple(map(_next, iterators))
-        except ZipExhausted:
-            pass
-        finally:
-            del chain
-
-isbn_regex = re.compile(r'([0-9\-xX]+)')
+isbn_regex = re.compile(r'([0-9\-]+)')
 
 class Record(object):
     """
@@ -106,14 +46,11 @@ class Record(object):
         self.leader = (' '*10) + '22' + (' '*8) + '4500'
         self.fields = list()
         self.pos = 0
-        self.force_utf8 = force_utf8
         if len(data) > 0:
             self.decode_marc(data, to_unicode=to_unicode,
                              force_utf8=force_utf8,
                              hide_utf8_warnings=hide_utf8_warnings,
                              utf8_handling=utf8_handling)
-        elif force_utf8:
-            self.leader = self.leader[0:9] + 'a' + self.leader[10:]
 
     def __str__(self):
         """
@@ -139,16 +76,6 @@ class Record(object):
             return fields[0]
         return None
 
-    def __contains__(self, tag):
-        """
-        Allows a shorthand test of tag membership:
-
-            '245' in record
-
-        """
-        fields = self.get_fields(tag)
-        return len(fields) > 0
-
     def __iter__(self):
         self.__pos = 0
         return self
@@ -166,56 +93,6 @@ class Record(object):
         """
         self.fields.extend(fields)
 
-    def add_grouped_field(self, *fields):
-        """
-        add_grouped_field() will add pymarc.Field objects to a Record object,
-        attempting to maintain a loose numeric order per the MARC standard for
-        "Organization of the record" (http://www.loc.gov/marc/96principl.html)
-        Optionally you can pass in multiple fields.
-        """
-        for f in fields:
-            if len(self.fields) == 0 or not f.tag.isdigit():
-                self.fields.append(f)
-                continue 
-            self._sort_fields(f, 'grouped')
-
-    def add_ordered_field(self, *fields):
-        """
-        add_ordered_field() will add pymarc.Field objects to a Record object,
-        attempting to maintain a strict numeric order.
-        Optionally you can pass in multiple fields.
-        """
-        for f in fields:
-            if len(self.fields) == 0 or not f.tag.isdigit():
-                self.fields.append(f)
-                continue 
-            self._sort_fields(f, 'ordered')
-
-    def _sort_fields(self, field, mode):
-        if mode == 'grouped':
-            tag = int(field.tag[0])
-        else:
-            tag = int(field.tag)
-
-        i, last_tag = 0, 0
-        for selff in self.fields:
-            i += 1
-            if not selff.tag.isdigit():
-                self.fields.insert(i - 1, field)
-                break
-
-            if mode == 'grouped':
-                last_tag = int(selff.tag[0])
-            else:
-                last_tag = int(selff.tag)
-
-            if last_tag > tag:
-                self.fields.insert(i - 1, field)
-                break
-            if len(self.fields) == i:
-                self.fields.append(field)
-                break
-
     def remove_field(self, *fields):
         """
         remove_field() will remove one or more pymarc.Field objects from
@@ -240,7 +117,7 @@ class Record(object):
 
             subjects = record.get_fields('600', '610', '650') 
 
-        If no tag is passed in to get_fields() a list of all the fields will be 
+        If no tag is passed in to fields() a list of all the fields will be 
         returned.
         """
         if (len(args) == 0):
@@ -296,34 +173,10 @@ class Record(object):
             else:
                 subfields = list()
                 subs = entry_data.split(SUBFIELD_INDICATOR)
-
-                # The MARC spec requires there to be two indicators in a
-                # field. However experience in the wild has shown that
-                # indicators are sometimes missing, and sometimes there
-                # are too many. Rather than throwing an exception because
-                # we can't find what we want and rejecting the field, or
-                # barfing on the whole record we'll try to use what we can
-                # find. This means missing indicators will be recorded as
-                # blank spaces, and any more than 2 are dropped on the floor.
-
-                first_indicator = second_indicator = ' '
-                if len(subs[0]) == 0:
-                    logging.warn("missing indicators: %s", entry_data)
-                    first_indicator = second_indicator = ' '
-                elif len(subs[0]) == 1:
-                    logging.warn("only 1 indicator found: %s", entry_data)
-                    first_indicator = subs[0][0]
-                    second_indicator = ' '
-                elif len(subs[0]) > 2:
-                    logging.warn("more than 2 indicators found: %s", entry_data)
-                    first_indicator = subs[0][0]
-                    second_indicator = subs[0][1]
-                else:
-                    first_indicator = subs[0][0]
-                    second_indicator = subs[0][1]
-
+                first_indicator = subs[0][0]
+                second_indicator = subs[0][1]
                 for subfield in subs[1:]:
-                    if len(subfield) == 0:
+                    if len(subfield) == 0: 
                         continue
                     code = subfield[0]
                     data = subfield[1:]
@@ -340,6 +193,7 @@ class Record(object):
                     indicators = [first_indicator, second_indicator], 
                     subfields = subfields,
                 )
+
             self.add_field(field)
             field_count += 1
 
@@ -359,9 +213,7 @@ class Record(object):
         # the field and the offset from the base address where the field data
         # can be found
         for field in self.fields:
-            field_data = field.as_marc()
-            if self.leader[9] == 'a' or self.force_utf8:
-              field_data = field_data.encode('utf-8')
+            field_data = field.as_marc().encode('utf-8')
             fields += field_data
             if field.tag.isdigit():
                 directory += '%03d' % int(field.tag)
@@ -389,41 +241,11 @@ class Record(object):
             (record_length, self.leader[5:12], base_address, self.leader[17:])
         
         # return the encoded record
-        if self.leader[9] == 'a' or self.force_utf8:
-            return self.leader.encode('utf-8') + directory.encode('utf-8') + fields
-        else:
-            return self.leader + directory + fields
+        return self.leader + directory + fields 
 
     # alias for backwards compatability
     as_marc21 = as_marc
 
-    def as_dict(self):
-        """
-        Turn a MARC record into a dictionary, which is used for ``as_json``.
-        """
-        record = {}
-        record['leader'] = self.leader
-        record['fields'] = []
-        for field in self:
-            if field.is_control_field():
-                record['fields'].append({field.tag: field.data})
-            else:
-                fd = {}
-                fd['subfields'] = []
-                fd['ind1'] = field.indicator1
-                fd['ind2'] = field.indicator2
-                for tag, value in izip_longest(*[iter(field.subfields)] * 2):
-                    fd['subfields'].append({tag: value})
-                record['fields'].append({field.tag: fd})
-        return record  # as dict
-
-    def as_json(self, **kwargs):
-        """
-        Serialize a record as JSON according to
-        http://dilettantes.code4lib.org/blog/2010/09/a-proposal-to-serialize-marc-in-json/
-        """
-        return json.dumps(self.as_dict(), **kwargs)
-
     def title(self):
         """
         Returns the title of the record (245 $a an $b).
@@ -442,8 +264,7 @@ class Record(object):
     def isbn(self):
         """
         Returns the first ISBN in the record or None if one is not
-        present. The returned ISBN will be all numeric, except for an
-        x/X which may occur in the checksum position.  Dashes and 
+        present. The returned ISBN will be all numberic; so dashes and 
         extraneous information will be automatically removed. If you need 
         this information you'll want to look directly at the 020 field, 
         e.g. record['020']['a']
