@@ -22,22 +22,6 @@ class MARC8Test(TestCase):
         utitle = r['240']['a']
         self.assertEquals(type(utitle), unicode)
         self.assertEquals(utitle, u'De la solitude \xe0 la communaut\xe9.')
-        
-    def test_marc8_reader_to_unicode_bad_eacc_sequence(self):
-        reader = MARCReader(file('test/bad_eacc_encoding.dat'), to_unicode=True, hide_utf8_warnings=True)
-        try:
-            r =  reader.next()
-            self.assertFalse("Was able to decode invalid MARC8") 
-        except UnicodeDecodeError:
-            self.assertTrue("Caught UnicodeDecodeError as expected") 
-
-    def test_marc8_reader_to_unicode_bad_escape(self):
-        reader = MARCReader(file('test/bad_marc8_escape.dat'), to_unicode=True)
-        r =  reader.next()
-        self.assertEquals(type(r), Record)
-        upublisher = r['260']['b']
-        self.assertEquals(type(upublisher), unicode)
-        self.assertEquals(upublisher, u'La Soci\xe9t\x1b,')
 
     def test_marc8_to_unicode(self):
         marc8_file = file('test/test_marc8.txt')
@@ -116,14 +100,6 @@ class MARC8Test(TestCase):
         self.assertEquals(utitle, u'De la solitude a' + unichr(0x0300) +
             ' la communaute' + unichr(0x0301) + '.')
 
-    def test_record_create_force_utf8(self, force_utf8=True):
-        r = Record(force_utf8=True)
-        self.assertEqual(r.leader[9], 'a')
-
-    def test_subscript_2(self):
-        self.assertEqual(marc8_to_unicode('CO\x1bb2\x1bs is a gas'), u'CO\u2082 is a gas')
-        self.assertEqual(marc8_to_unicode('CO\x1bb2\x1bs'), u'CO\u2082')
-
 def suite():
     test_suite = makeSuite(MARC8Test, 'test')
     return test_suite 
